==> scijava-common-2.44.0-sources.jar: org/scijava/console/AbstractConsoleArgument.java <==
/*
 * #%L
 * SciJava Common shared library for SciJava software.
 * %%
 * Copyright (C) 2009 - 2015 Board of Regents of the University of
 * Wisconsin-Madison, Broad Institute of MIT and Harvard, and Max Planck
 * Institute of Molecular Cell Biology and Genetics.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * #L%
 */

package org.scijava.console;

import java.util.LinkedList;

import org.scijava.plugin.AbstractHandlerPlugin;

/**
 * Abstract superclass of {@link ConsoleArgument} implementations.
 *
 * @author Curtis Rueden
 */
public abstract class AbstractConsoleArgument extends
	AbstractHandlerPlugin<LinkedList<String>> implements ConsoleArgument
{

	// -- Typed methods --

	@Override
	@SuppressWarnings({ "rawtypes", "unchecked" })
	public Class<LinkedList<String>> getType() {
		return (Class) String.class;
	}

}

==> scijava-common-2.52.1-sources.jar: org/scijava/console/AbstractConsoleArgument.java <==
/*
 * #%L
 * SciJava Common shared library for SciJava software.
 * %%
 * Copyright (C) 2009 - 2016 Board of Regents of the University of
 * Wisconsin-Madison, Broad Institute of MIT and Harvard, and Max Planck
 * Institute of Molecular Cell Biology and Genetics.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * #L%
 */

package org.scijava.console;

import java.util.HashSet;
import java.util.LinkedList;
import java.util.Set;

import org.scijava.plugin.AbstractHandlerPlugin;

/**
 * Abstract superclass of {@link ConsoleArgument} implementations.
 *
 * @author Curtis Rueden
 */
public abstract class AbstractConsoleArgument extends
	AbstractHandlerPlugin<LinkedList<String>> implements ConsoleArgument
{
	private int numArgs;
	private Set<String> aliasFlags;

	public AbstractConsoleArgument() {
		this(1, new String[0]);
	}

	public AbstractConsoleArgument(final String... aliases) {
		this(1, aliases);
	}
	
	public AbstractConsoleArgument(final int requiredArgs, final String... aliases) {
		numArgs = requiredArgs;
		aliasFlags = new HashSet<String>();
		for (final String s : aliases) aliasFlags.add(s);
	}

	// -- Typed methods --

	@Override
	public boolean supports(final LinkedList<String> args) {
		if (args == null || args.size() < numArgs) return false;
		return isAlias(args);
	}

	@Override
	@SuppressWarnings({ "rawtypes", "unchecked" })
	public Class<LinkedList<String>> getType() {
		return (Class) String.class;
	}

	/**
	 * @return true if there are no aliases for this {@code ConsoleArgument}, or
	 *         at least one alias matches the first argument in the provided
	 *         list
	 */
	protected boolean isAlias(final LinkedList<String> args) {
		return aliasFlags.isEmpty() || aliasFlags.contains(args.getFirst());
	}
}
